#ifndef ENDWINDOW_H
#define ENDWINDOW_H

#include <QDialog>

namespace Ui {
    class EndWindow;
}

class EndWindow : public QDialog
{
    Q_OBJECT

public:
    enum EndResults
    {
        None,
        Load,
        MainMenu,
        Quit,
        Restart
    };

    explicit EndWindow(QWidget *parent = 0);
    ~EndWindow();

    int GetResult();

private:
    Ui::EndWindow *ui;

    int m_Result;

private slots:
    void LoadSlot();
    void MainMenuSlot();
    void RestartSlot();
    void QuitSlot();

};

#endif // ENDWINDOW_H
